@@ -1,5 +1,5 @@
 /*
-    This file is part of audtty, copyright 2008-2009 Chris Taylor.
+    This file is part of audtty, copyright 2008-2010 Chris Taylor.
 
     audtty is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,9 +37,12 @@ win browser;
 controller cont;
 extern struct timespec interval;
 
+int sort_abc(const void *x, const void *y) {
+  return (g_strcmp0(*(const char **)x, *(const char **)y));
+}
+
 
 void get_contents( void );
-void sort( void );
 void swap(gchar** tmp1, gchar** tmp2);
 void browser_paint(controller *display);
 gboolean check_dir( void );
@@ -159,9 +162,9 @@ void get_contents( void )
         gchar *name;
         GDir *dir;
 	GError *open_error=NULL;
-        GError *convert_error=NULL;
         
-	cont.first=0;
+
+        cont.first=0;
 	cont.pos_height=0;
 
 	werase(browser.location);
@@ -170,7 +173,7 @@ void get_contents( void )
 	waddstr(browser.location, g_get_current_dir());
 	wnoutrefresh(browser.location);
 
-        for(i=0;i<=cont.length;i++)
+        for(i=0;i<=cont.length+1;i++)
         {
             cont.files[i].file=NULL;
         }
@@ -179,6 +182,7 @@ void get_contents( void )
         if(!dir)
         {
             display_error(open_error->message, cont.location, true);
+            g_error_free(open_error);
             return;
         }
         else
@@ -187,53 +191,23 @@ void get_contents( void )
             cont.files[1].file="..";
             while((name=(gchar*)g_dir_read_name(dir)))
             {
+                    GError *convert_error=NULL;
                     cont.files[count].file=g_filename_to_utf8(name,-1,NULL,NULL,&convert_error);
                     if(convert_error)
                     {
+                        cont.files[count].file=name;
                         display_error(convert_error->message, name, false);
-                        convert_error=NULL;
                     }
+                    if(convert_error!=NULL)
+                        g_error_free(convert_error);
                     count++;
             }
             cont.length=count;
-            sort();
+            qsort(cont.files, cont.length, sizeof(files), &sort_abc);
             g_dir_close(dir);
         }
         browser_paint(&cont);
         g_free(name);
-        if(open_error)
-            g_error_free(open_error);
-        if(convert_error)
-            g_error_free(convert_error);
-}
-
-void sort( void )
-{
-	gint i, j;
-	gint min;
-	for (i = 0; i <= cont.length; i++)
-	{
-		min = i;
-		for (j = i + 1; j < cont.length; j++)
-		{
-			if(cont.files[min].file==NULL||cont.files[j].file==NULL)
-				continue;
-                        else if (g_strcmp0(cont.files[min].file,cont.files[j].file) > 0)
-			{
-					min = j;
-			}
-		}
-		swap(&cont.files[i].file, &cont.files[min].file);
-	}
-}
-
-void swap(gchar** tmp1, gchar** tmp2)
-{
-	gchar *tmp;
-
-	tmp = *tmp1;
-	*tmp1 = *tmp2;
-	*tmp2 = tmp;
 }
 
 gboolean check_dir( void )
