@@ -13,9 +13,9 @@
   along with this package; if not, write to the Free Software
   Foundation, 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef _XMMS_DBUS_H_
+#ifndef _DBUS_H_
 
-#define _XMMS_DBUS_H_
+#define _DBUS_H_
 
 #include <audacious/dbus.h>
 
