@@ -16,29 +16,29 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _XMMS_PLAYLIST_H_
+#ifndef _PLAYLIST_H_
 
-#define _XMMS_PLAYLIST_H_
+#define _PLAYLIST_H_
 
 typedef struct {
-	char *title;
-	char *file;
-	int length;
+	gchar *title;
+	gchar *file;
+	gint length;
 } song;
 
 typedef struct {
-	int pos;
-	int prev_pos;
-	int length;
-	int selector;
-	int scrolledto;
+	gint pos;
+	gint prev_pos;
+	gint length;
+	gint selector;
+	gint scrolledto;
 	song *song;
-	int *song_mask;
+	gint *song_mask;
 } playlist;
 
 void playlist_paint(playlist *plist);
-void playlist_read(int length);
-int song_length(int song);
-char *song_title(int song);
+void playlist_read(gint length);
+gint song_length(gint song);
+gchar *song_title(gint song);
 
 #endif
