@@ -100,6 +100,7 @@ static void shortoptions(gchar cmd, gint state)
 			sprintf(tmp, "-%c", cmd);
 			unknown_option(tmp);
 	}
+        g_free(tmp);
 }
 
 static void longoptions(gchar *input)
@@ -138,6 +139,7 @@ static void parse_line(gchar *file, gchar *line)
 	while (*line == ' ' || *line == '\t') ++line;
 	if (*line == '\0') return;
 	longoptions(line);
+        g_free(end);
 }
 
 static void read_file(gchar *file)
@@ -158,10 +160,12 @@ static void read_file(gchar *file)
 		while (fgets(buffer, CONFIG_MAX_LINE_LENGTH, fd) != NULL) {
 			parse_line(file, buffer);
 		}
+                g_free(buffer);
 	} else {
 		fprintf(stderr, "Warning: Error %d while opening %s: %s\n", 
 				errno, file, strerror(errno));
 	}
+        fclose(fd);
 }
 
 void read_conffiles(void)
@@ -192,6 +196,7 @@ void arguments(gint argc, gchar *argv[])
 			state = *pos++ == '-';
 			while (*pos != '\0')
 				shortoptions(*pos++, state);
+                        g_free(pos);
 		}
 		
 		// Long options
@@ -201,5 +206,7 @@ void arguments(gint argc, gchar *argv[])
 		} else {
 			unknown_option(input);
 		}
+                g_free(input);
 	}
+
 }
