@@ -16,12 +16,12 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _XMMS_SETTINGS_H_
+#ifndef _SETTINGS_H_
 
-#define _XMMS_SETTINGS_H_
+#define _SETTINGS_H_
 
 void set_defaults(void);
 void read_conffiles(void);
-void arguments(int argc, char *argv[]);
+void arguments(gint argc, gchar *argv[]);
 
 #endif
